@@ -307,11 +307,13 @@ typedef void (*SVC_SETUP_CALLBACK) (HANDLE   lc_elan_handle,
 * Postconditions:
 *   The p_la_handle is valid.
 --*/
-STATUS la_create (HANDLE                lc_handle,
-                  ARP_XMT_CALLBACK      arp_xmt_callback,
-                  FLUSH_XMT_CALLBACK    flush_xmt_callback,
-                  SVC_SETUP_CALLBACK    svc_setup_callback,
-                  HANDLE               *p_la_handle);
+STATUS la_create (HANDLE              lc_handle,
+                  ARP_XMT_CALLBACK    arp_xmt_callback,
+                  FLUSH_XMT_CALLBACK  flush_xmt_callback,
+                  SVC_SETUP_CALLBACK  svc_setup_callback,
+                  void                (*associate_req_callback)(HANDLE lc_elan_handle,
+                                                                int sizeoftlvs),  /* LANE2 */
+                  HANDLE              *p_la_handle);
 
 /*++
 * ==============
@@ -444,7 +446,8 @@ void la_config (HANDLE     la_elan_handle,
                 UINT16     forward_delay_time,
                 UINT16     le_arp_response_time,
                 UINT16     flush_timeout,
-                UINT16     path_switching_delay);
+                UINT16     path_switching_delay,
+                unsigned int lane_version_num); /* LANE2 */
 
 /*++
 * =================
@@ -538,12 +541,14 @@ STATUS la_addr_delete (HANDLE    la_elan_handle,
 *   flush mechanism is invoked to facilitate the path switch.
 *   LANE2: The TLV association is also up-to-date
 --*/
-void la_arp_update (HANDLE    la_elan_handle,
-                    ESI       esi,
-                    ADDR_ATM  addr_atm,
-                    BOOLEAN   remote_flag,
-                    char      *tlv_list,
-                    int       sizeoftlvs);
+void la_arp_update (HANDLE       la_elan_handle,
+                    ESI          esi,
+                    ADDR_ATM     addr_atm,
+                    BOOLEAN      remote_flag,
+                    char         *tlv_list,
+                    int          sizeoftlvs,
+                    int          targetless_le_arp,
+                    int          no_source_le_narp);
 
 /*++
 * =====================
