@@ -149,8 +149,7 @@ static int search(FILE *file,char *buffer,int length,
 	      ((const struct sockaddr_atmpvc *) addr)->sap_addr.vci !=
 	      ((struct sockaddr_atmpvc *) &temp)->sap_addr.vci) continue;
 	}
-	else if (!atm_equal((const struct sockaddr_atmsvc *) addr,
-	      (struct sockaddr_atmsvc *) &temp,0,0)) continue;
+	else if (!atm_equal(addr,(struct sockaddr *) &temp,0,0)) continue;
         while ((here = strtok(NULL,"\t\n ")))
 	    if (strlen(here) < length) {
 		strcpy(buffer,here);
