@@ -267,7 +267,7 @@ static void trace_on_exit(int status,void *dummy)
     FILE *file;
 
     if (!status) return;
-    if (dump_dir) file = stderr;
+    if (!dump_dir) file = stderr;
     else {
 	sprintf(path,"atmsigd.%d.trace.exit",getpid());
 	if (!(file = fopen(path,"w"))) {
