@@ -44,7 +44,7 @@ typedef struct _var {
 } VAR;
 
 
-extern int quiet;
+extern int quiet,verbose;
 extern VAR *variables;
 
 
@@ -63,6 +63,6 @@ VALUE_TYPE type_of(int field);
 
 void send_msg(const struct atmsvc_msg *msg);
 void recv_msg(struct atmsvc_msg *msg);
-void dump_msg(const struct atmsvc_msg *msg);
+void dump_msg(const char *prefix,const struct atmsvc_msg *msg);
 
 #endif
